pub struct ComputedStyleExtraFields {
pub is_appearance_base: bool,
}Fields
is_appearance_base: boolReturns whether or not this node is being rendered with base appearance, which happens when it has its appearance property set to base/base-select or it is in the subtree of an element being rendered with base appearance.
Implementations
Sourceimpl ComputedStyleExtraFields
impl ComputedStyleExtraFields
pub fn new(is_appearance_base: impl Into<bool>) -> ComputedStyleExtraFields
Sourceimpl ComputedStyleExtraFields
impl ComputedStyleExtraFields
pub const IDENTIFIER: &'static str = "CSS.ComputedStyleExtraFields"