pub enum CorsError {
Show 28 variants
DisallowedByMode,
InvalidResponse,
WildcardOriginNotAllowed,
MissingAllowOriginHeader,
MultipleAllowOriginValues,
InvalidAllowOriginValue,
AllowOriginMismatch,
InvalidAllowCredentials,
CorsDisabledScheme,
PreflightInvalidStatus,
PreflightDisallowedRedirect,
PreflightWildcardOriginNotAllowed,
PreflightMissingAllowOriginHeader,
PreflightMultipleAllowOriginValues,
PreflightInvalidAllowOriginValue,
PreflightAllowOriginMismatch,
PreflightInvalidAllowCredentials,
PreflightMissingAllowExternal,
PreflightInvalidAllowExternal,
InvalidAllowMethodsPreflightResponse,
InvalidAllowHeadersPreflightResponse,
MethodDisallowedByPreflightResponse,
HeaderDisallowedByPreflightResponse,
RedirectContainsCredentials,
InsecureLocalNetwork,
InvalidLocalNetworkAccess,
NoCorsRedirectModeNotFollow,
LocalNetworkAccessPermissionDenied,
}Expand description
The reason why request was blocked.
Variants
DisallowedByMode
InvalidResponse
WildcardOriginNotAllowed
MissingAllowOriginHeader
MultipleAllowOriginValues
InvalidAllowOriginValue
AllowOriginMismatch
InvalidAllowCredentials
CorsDisabledScheme
PreflightInvalidStatus
PreflightDisallowedRedirect
PreflightWildcardOriginNotAllowed
PreflightMissingAllowOriginHeader
PreflightMultipleAllowOriginValues
PreflightInvalidAllowOriginValue
PreflightAllowOriginMismatch
PreflightInvalidAllowCredentials
PreflightMissingAllowExternal
TODO(https://crbug.com/1263483): Remove this once frontend code does not reference it anymore.
PreflightInvalidAllowExternal
TODO(https://crbug.com/1263483): Remove this once frontend code does not reference it anymore.
InvalidAllowMethodsPreflightResponse
InvalidAllowHeadersPreflightResponse
MethodDisallowedByPreflightResponse
HeaderDisallowedByPreflightResponse
RedirectContainsCredentials
InsecureLocalNetwork
Request was a private network request initiated by a non-secure context.
InvalidLocalNetworkAccess
Request carried a target IP address space property that did not match the target resource’s address space.
NoCorsRedirectModeNotFollow
LocalNetworkAccessPermissionDenied
Request was a local network request and is denied by user permission. https://wicg.github.io/local-network-access/