pub struct CookieParam {Show 13 fields
pub name: String,
pub value: String,
pub url: Option<String>,
pub domain: Option<String>,
pub path: Option<String>,
pub secure: Option<bool>,
pub http_only: Option<bool>,
pub same_site: Option<CookieSameSite>,
pub expires: Option<TimeSinceEpoch>,
pub priority: Option<CookiePriority>,
pub source_scheme: Option<CookieSourceScheme>,
pub source_port: Option<i64>,
pub partition_key: Option<CookiePartitionKey>,
}Expand description
Cookie parameter object CookieParam
Fields
name: StringCookie name.
value: StringCookie value.
url: Option<String>The request-URI to associate with the setting of the cookie. This value can affect the default domain, path, source port, and source scheme values of the created cookie.
domain: Option<String>Cookie domain.
path: Option<String>Cookie path.
secure: Option<bool>True if cookie is secure.
http_only: Option<bool>True if cookie is http-only.
same_site: Option<CookieSameSite>Cookie SameSite type.
expires: Option<TimeSinceEpoch>Cookie expiration date, session cookie if not set
priority: Option<CookiePriority>Cookie Priority.
source_scheme: Option<CookieSourceScheme>Cookie source scheme type.
source_port: Option<i64>Cookie source port. Valid values are {-1, [1, 65535]}, -1 indicates an unspecified port. An unspecified port value allows protocol clients to emulate legacy cookie scope for the port. This is a temporary ability and it will be removed in the future.
partition_key: Option<CookiePartitionKey>Cookie partition key. If not set, the cookie will be set as not partitioned.
Implementations
Sourceimpl CookieParam
impl CookieParam
Sourceimpl CookieParam
impl CookieParam
pub fn builder() -> CookieParamBuilder
Sourceimpl CookieParam
impl CookieParam
pub const IDENTIFIER: &'static str = "Network.CookieParam"