pub struct RefreshEventDetails {
pub refresh_result: RefreshEventDetailsRefreshResult,
pub fetch_result: Option<DeviceBoundSessionFetchResult>,
pub new_session: Option<DeviceBoundSession>,
pub was_fully_proactive_refresh: bool,
}Expand description
Session event details specific to refresh. RefreshEventDetails
Fields
refresh_result: RefreshEventDetailsRefreshResultThe result of a refresh.
fetch_result: Option<DeviceBoundSessionFetchResult>If there was a fetch attempt, the result of that.
new_session: Option<DeviceBoundSession>The session display if there was a newly created session. This is populated for any refresh event that modifies the session config.
was_fully_proactive_refresh: boolSee comments on net::device_bound_sessions::RefreshEventResult::was_fully_proactive_refresh.
Implementations
Sourceimpl RefreshEventDetails
impl RefreshEventDetails
pub fn new( refresh_result: impl Into<RefreshEventDetailsRefreshResult>, was_fully_proactive_refresh: impl Into<bool>, ) -> RefreshEventDetails
Sourceimpl RefreshEventDetails
impl RefreshEventDetails
pub fn builder() -> RefreshEventDetailsBuilder
Sourceimpl RefreshEventDetails
impl RefreshEventDetails
pub const IDENTIFIER: &'static str = "Network.RefreshEventDetails"