pub struct EventInspectPanelShowRequested {
pub backend_node_id: BackendNodeId,
}Expand description
Fired when user asks to show the Inspect panel. inspectPanelShowRequested
Fields
backend_node_id: BackendNodeIdId of the node to show in the panel.
Implementations
Sourceimpl EventInspectPanelShowRequested
impl EventInspectPanelShowRequested
pub const IDENTIFIER: &'static str = "Overlay.inspectPanelShowRequested"