pub struct EventInspectedElementWindowRestored {
pub backend_node_id: BackendNodeId,
}Expand description
Fired when user asks to restore the Inspected Element floating window. inspectedElementWindowRestored
Fields
backend_node_id: BackendNodeIdId of the node to restore the floating window for.
Implementations
Sourceimpl EventInspectedElementWindowRestored
impl EventInspectedElementWindowRestored
pub const IDENTIFIER: &'static str = "Overlay.inspectedElementWindowRestored"