pub enum TargetMessage {
Show 16 variants
Command(CommandMessage),
MainFrame(Sender<Option<FrameId>>),
AllFrames(Sender<Vec<FrameId>>),
Url(GetUrl),
Name(GetName),
Parent(GetParent),
WaitForNavigation(Sender<ArcHttpRequest>),
WaitForDomContentLoaded(Sender<ArcHttpRequest>),
WaitForLoad(Sender<ArcHttpRequest>),
WaitForNetworkIdle(Sender<ArcHttpRequest>),
WaitForNetworkAlmostIdle(Sender<ArcHttpRequest>),
AddEventListener(EventListenerRequest),
GetExecutionContext(GetExecutionContext),
Authenticate(Credentials),
BlockNetwork(bool),
EnableInterception(bool),
}Variants
Command(CommandMessage)
Execute a command within the session of this target
MainFrame(Sender<Option<FrameId>>)
Return the main frame of this target’s page
AllFrames(Sender<Vec<FrameId>>)
Return all the frames of this target’s page
Url(GetUrl)
Return the url if available
Name(GetName)
Return the name if available
Parent(GetParent)
Return the parent id of a frame
A Message that resolves when the frame finished loading a new url
WaitForDomContentLoaded(Sender<ArcHttpRequest>)
Resolves when DOMContentLoaded fires (HTML parsed, sync scripts
executed) — before load, so subresources may still be in-flight.
WaitForLoad(Sender<ArcHttpRequest>)
Resolves when the load event fires — all subresources (images,
fonts, XHRs) are done. Slower than WaitForNavigation through proxies.
WaitForNetworkIdle(Sender<ArcHttpRequest>)
A Message that resolves when the frame network is idle
WaitForNetworkAlmostIdle(Sender<ArcHttpRequest>)
A Message that resolves when the frame network is almost idle
AddEventListener(EventListenerRequest)
A request to submit a new listener that gets notified with every received event
GetExecutionContext(GetExecutionContext)
Get the ExecutionContext if available
Authenticate(Credentials)
BlockNetwork(bool)
Set block/unblocked networking
EnableInterception(bool)
Enable/Disable internal request paused interception