EventListeners

Struct EventListeners 

pub struct EventListeners { /* private fields */ }
All the currently active listeners

Implementations

Source

impl EventListeners

pub fn add_listener(&mut self, req: EventListenerRequest) -> EventListenerHandle

Register a subscription for a method, returning a handle to remove it.

pub fn remove_listener(&mut self, handle: &EventListenerHandle) -> bool

Remove a specific listener immediately. Returns true if something was removed.

pub fn remove_all_for_method(&mut self, method: &MethodId) -> usize

Remove all listeners for a given method. Returns how many were removed.

pub fn start_send<T: Event>(&mut self, event: T)

Queue in an event that should be sent to all listeners.

pub fn try_send_custom(&mut self, method: &str, val: Value) -> Result<()>

Try to queue a custom event if a listener is registered and the json conversion succeeds.

pub fn poll(&mut self, cx: &mut Context<'_>)

Drains all queued events and does housekeeping when the receiver is dropped.