pub struct CreateTargetParams {Show 13 fields
pub url: String,
pub left: Option<i64>,
pub top: Option<i64>,
pub width: Option<i64>,
pub height: Option<i64>,
pub window_state: Option<WindowState>,
pub browser_context_id: Option<BrowserContextId>,
pub enable_begin_frame_control: Option<bool>,
pub new_window: Option<bool>,
pub background: Option<bool>,
pub for_tab: Option<bool>,
pub hidden: Option<bool>,
pub focus: Option<bool>,
}Expand description
Creates a new page. createTarget
Fields
url: StringThe initial URL the page will be navigated to. An empty string indicates about:blank.
left: Option<i64>Frame left origin in DIP (requires newWindow to be true or headless shell).
top: Option<i64>Frame top origin in DIP (requires newWindow to be true or headless shell).
width: Option<i64>Frame width in DIP (requires newWindow to be true or headless shell).
height: Option<i64>Frame height in DIP (requires newWindow to be true or headless shell).
window_state: Option<WindowState>Frame window state (requires newWindow to be true or headless shell). Default is normal.
browser_context_id: Option<BrowserContextId>The browser context to create the page in.
enable_begin_frame_control: Option<bool>Whether BeginFrames for this target will be controlled via DevTools (headless shell only, not supported on MacOS yet, false by default).
new_window: Option<bool>Whether to create a new Window or Tab (false by default, not supported by headless shell).
background: Option<bool>Whether to create the target in background or foreground (false by default, not supported by headless shell).
for_tab: Option<bool>Whether to create the target of type “tab”.
Whether to create a hidden target. The hidden target is observable via protocol, but not
present in the tab UI strip. Cannot be created with forTab: true, newWindow: true or
background: false. The life-time of the tab is limited to the life-time of the session.
focus: Option<bool>If specified, the option is used to determine if the new target should be focused or not. By default, the focus behavior depends on the value of the background field. For example, background=false and focus=false will result in the target tab being opened but the browser window remain unchanged (if it was in the background, it will remain in the background) and background=false with focus=undefined will result in the window being focused. Using background: true and focus: true is not supported and will result in an error.
Implementations
Sourceimpl CreateTargetParams
impl CreateTargetParams
pub fn new(url: impl Into<String>) -> CreateTargetParams
Sourceimpl CreateTargetParams
impl CreateTargetParams
pub fn builder() -> CreateTargetParamsBuilder
Sourceimpl CreateTargetParams
impl CreateTargetParams
pub const IDENTIFIER: &'static str = "Target.createTarget"