pub struct EventListeners { /* private fields */ }Expand description
All the currently active listeners
Implementations
Sourceimpl EventListeners
impl EventListeners
Sourcepub fn add_listener(&mut self, req: EventListenerRequest) -> EventListenerHandle
pub fn add_listener(&mut self, req: EventListenerRequest) -> EventListenerHandle
Register a subscription for a method, returning a handle to remove it.
Sourcepub fn remove_listener(&mut self, handle: &EventListenerHandle) -> bool
pub fn remove_listener(&mut self, handle: &EventListenerHandle) -> bool
Remove a specific listener immediately. Returns true if something was removed.
Sourcepub fn remove_all_for_method(&mut self, method: &MethodId) -> usize
pub fn remove_all_for_method(&mut self, method: &MethodId) -> usize
Remove all listeners for a given method. Returns how many were removed.
Sourcepub fn start_send<T: Event>(&mut self, event: T)
pub fn start_send<T: Event>(&mut self, event: T)
Queue in an event that should be sent to all listeners.